<?xml version="1.0" encoding="UTF-8"?>
<?xml-stylesheet type="text/xml"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Base Tag -->
<xsl:template match="/">
	<html lang="ja">
		<xsl:apply-templates />
	</html>
</xsl:template>

<xsl:template match="document">
	<xsl:apply-templates />
	<body>
		<h1>
			<xsl:value-of select="info/project" />
			<span class="mini"> - <xsl:value-of select="info/concept" /> </span>
		</h1>
		<h3>
			<span class="mini">version.</span> <xsl:value-of select="info/version" /><br/>
			<span class="mini">author. </span> <xsl:value-of select="info/author" /><br/>
			<xsl:element name="a">
				<xsl:attribute name="href">
					<xsl:value-of select="info/url" />
				</xsl:attribute>
				<xsl:value-of select="info/url" />
			</xsl:element>
		</h3>
		
		<h4>
			API List
		</h4>
		<ul>
			<xsl:for-each select="api">
				<li>
					<xsl:choose>
						<xsl:when test="@href">
							<xsl:for-each select="document(@href)/api">
								<xsl:call-template name="api_description" />
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="api_description" />
						</xsl:otherwise>
					</xsl:choose>
				</li>
				</xsl:for-each>
		</ul>
		
		
		<h4>
			API Reference
		</h4>
		<ul>
			<xsl:for-each select="api">
				<li>
					<xsl:choose>
						<xsl:when test="@href">
							<xsl:for-each select="document(@href)/api">
								<xsl:call-template name="api_description">
									<xsl:with-param name="detailed">yes</xsl:with-param>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="api_description">
								<xsl:with-param name="detailed">yes</xsl:with-param>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</li>
			</xsl:for-each>
		</ul>
		
		<div class="copyright">
			<xsl:copy-of select="//info/copyright" />
		</div>
		
	</body>
</xsl:template>

<xsl:template name="api_brief">
	<span class="type">
		<xsl:value-of select="return/type" />
	</span>
	<span class="api">
		<xsl:value-of select="name" />
	</span>
	(
	<xsl:for-each select="parameter">
		<span class="type">
			<xsl:copy-of select="type" />
		</span>
		<span class="foo">
			<xsl:copy-of select="name" />
		</span>
		<xsl:if test="initial">
		 = <span class="initial"><xsl:value-of select="initial" /></span>
		</xsl:if>
		<xsl:if test="position()!=last()">, </xsl:if>
	</xsl:for-each>
	)
</xsl:template>

<xsl:template name="api_description">
	<xsl:param name="detailed">no</xsl:param>
	
	<xsl:choose>
		<xsl:when test="$detailed='no'">
			<a>
				<xsl:attribute name="href">#<xsl:value-of select="name" /></xsl:attribute>
				<xsl:call-template name="api_brief" />
			</a>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="api_brief" />
			<a>
				<xsl:attribute name="name"><xsl:value-of select="name" /></xsl:attribute>
			</a>
			<div class="description">
				<xsl:copy-of select="description/." />
			</div>
			<ul>
				<xsl:for-each select="parameter">
					<li>
						<span class="type"><xsl:copy-of select="type" /></span>
						<span class="foo"><xsl:copy-of select="name" /></span>
						<div class="description">
							<xsl:copy-of select="description/." />
						</div>
					</li>
				</xsl:for-each>
			</ul>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="info">
	<head>
		<xsl:element name="title">
			API Reference - <xsl:value-of select="project" />
		</xsl:element>
		<link rel="stylesheet" type="text/css" href="css.css" />
		<xsl:for-each select="stylesheet">
			<xsl:element name="link">
				<xsl:attribute name="rel">
					stylesheet
				</xsl:attribute>
				<xsl:attribute name="href">
					<xsl:value-of select="text()" />
				</xsl:attribute>
			</xsl:element>
		</xsl:for-each>
	</head>
</xsl:template>

<xsl:template match="br">
    <br/>
</xsl:template>

<xsl:template match="description">
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="*">
</xsl:template>

</xsl:stylesheet>